This is an automated email from the ASF dual-hosted git repository.
dependabot[bot] pushed a change to branch
dependabot/pip/streampipes-client-python/mkdocs-jupyter-0.26.3
in repository https://gitbox.apache.org/repos/asf/streampipes.git
discard ecf7e2b47d chore(deps-dev): bump mkdocs-jupyter in
/streampipes-client-python
add 671d9009e9 chore(deps-dev): bump cypress from 16.1.0 to 16.2.0 in /ui
(#5176)
add c8196cda4c chore(deps): bump marked from 18.0.7 to 18.1.1 in /ui
(#5173)
add 71cb7f5f35 chore(deps): bump grpc.version from 1.84.0 to 1.85.1 (#5174)
add 15053db271 chore(deps-dev): bump pre-commit from 4.6.0 to 4.6.2 in
/streampipes-client-python (#5177)
add 8dee5876f5 chore(deps): bump com.puppycrawl.tools:checkstyle from
14.1.0 to 14.3.0 (#5149)
add b01b9441a9 refactor: Let labels and sites use asset resource (#5171)
add 2e62be6922 chore(deps-dev): bump mkdocs-jupyter in
/streampipes-client-python
This update added new revisions after undoing existing revisions.
That is to say, some revisions that were in the old version of the
branch are not in the new version. This situation occurs
when a user --force pushes a change and generates a repository
containing something like this:
* -- * -- B -- O -- O -- O (ecf7e2b47d)
\
N -- N -- N
refs/heads/dependabot/pip/streampipes-client-python/mkdocs-jupyter-0.26.3
(2e62be6922)
You should already have received notification emails for all of the O
revisions, and so the following emails describe only the N revisions
from the common base, B.
Any revisions marked "omit" are not gone; other references still
refer to them. Any revisions marked "discard" are gone forever.
No new revisions were added by this update.
Summary of changes:
pom.xml | 4 +--
streampipes-client-python/poetry.lock | 8 ++---
streampipes-client-python/pyproject.toml | 2 +-
ui/package-lock.json | 16 ++++-----
ui/package.json | 4 +--
.../src/lib/apis/labels.service.ts | 17 ++++-----
.../assets/dialog/base-asset-links.directive.ts | 2 --
.../site-area-configuration.component.ts | 40 +++++++++-------------
8 files changed, 42 insertions(+), 51 deletions(-)